"""HasArtifact linked to PythonPackageVersionEntity

Revision ID: a8a4748e85cb
Revises: 331cbc965699
Create Date: 2019-10-09 12:26:39.197782+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'a8a4748e85cb'
down_revision = '331cbc965699'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('has_artifact', sa.Column('python_package_version_entity_id', sa.Integer(), nullable=False))
    op.create_foreign_key(None, 'has_artifact', 'python_package_version_entity', ['python_package_version_entity_id'], ['id'], ondelete='CASCADE')
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_constraint(None, 'has_artifact', type_='foreignkey')
    op.drop_column('has_artifact', 'python_package_version_entity_id')
    # ### end Alembic commands ###



"""Modify datatype for metadata

Revision ID: 8231fee9a210
Revises: 3dce903da79a
Create Date: 2019-11-25 10:32:29.831130+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '8231fee9a210'
down_revision = '3dce903da79a'
branch_labels = None
depends_on = None

def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.alter_column('python_package_metadata', 'author', type_=sa.Text, existing_type=sa.VARCHAR)
    op.alter_column('python_package_metadata', 'author_email', type_=sa.Text, existing_type=sa.VARCHAR)
    op.alter_column('python_package_metadata', 'download_url', type_=sa.Text, existing_type=sa.VARCHAR)
    op.alter_column('python_package_metadata', 'home_page', type_=sa.Text, existing_type=sa.VARCHAR)
    op.alter_column('python_package_metadata', 'keywords', type_=sa.Text, existing_type=sa.VARCHAR)
    op.alter_column('python_package_metadata', 'license', type_=sa.Text, existing_type=sa.VARCHAR)
    op.alter_column('python_package_metadata', 'maintainer', type_=sa.Text, existing_type=sa.VARCHAR)
    op.alter_column('python_package_metadata', 'maintainer_email', type_=sa.Text, existing_type=sa.VARCHAR)
    op.alter_column('python_package_metadata', 'metadata_version', type_=sa.Text, existing_type=sa.VARCHAR)
    op.alter_column('python_package_metadata', 'name', type_=sa.Text, existing_type=sa.VARCHAR)
    op.alter_column('python_package_metadata', 'summary', type_=sa.Text, existing_type=sa.VARCHAR)
    op.alter_column('python_package_metadata', 'version', type_=sa.Text, existing_type=sa.VARCHAR)
    op.alter_column('python_package_metadata', 'requires_python', type_=sa.Text, existing_type=sa.VARCHAR)
    op.alter_column('python_package_metadata', 'description', type_=sa.Text, existing_type=sa.VARCHAR)
    op.alter_column('python_package_metadata', 'description_content_type', type_=sa.Text, existing_type=sa.VARCHAR)

    op.alter_column('python_package_metadata_classifier', 'classifier', type_=sa.Text, existing_type=sa.VARCHAR)

    op.alter_column('python_package_metadata_platform', 'platform', type_=sa.Text, existing_type=sa.VARCHAR)

    op.alter_column('python_package_metadata_supported_platform', 'supported_platform', type_=sa.Text, existing_type=sa.VARCHAR)

    op.alter_column('python_package_metadata_requires_external', 'dependency', type_=sa.Text, existing_type=sa.VARCHAR)

    op.alter_column('python_package_metadata_project_url', 'project_url', type_=sa.Text, existing_type=sa.VARCHAR)

    op.alter_column('python_package_metadata_provides_extra', 'optional_feature', type_=sa.Text, existing_type=sa.VARCHAR)

    op.alter_column('python_package_metadata_distutils', 'distutils', type_=sa.Text, existing_type=sa.VARCHAR)

    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.alter_column('python_package_metadata', 'author', type_=sa.String, existing_type=sa.VARCHAR)
    op.alter_column('python_package_metadata', 'author_email', type_=sa.String, existing_type=sa.VARCHAR)
    op.alter_column('python_package_metadata', 'download_url', type_=sa.String, existing_type=sa.VARCHAR)
    op.alter_column('python_package_metadata', 'home_page', type_=sa.String, existing_type=sa.VARCHAR)
    op.alter_column('python_package_metadata', 'keywords', type_=sa.String, existing_type=sa.VARCHAR)
    op.alter_column('python_package_metadata', 'license', type_=sa.String, existing_type=sa.VARCHAR)
    op.alter_column('python_package_metadata', 'maintainer', type_=sa.String, existing_type=sa.VARCHAR)
    op.alter_column('python_package_metadata', 'maintainer_email', type_=sa.String, existing_type=sa.VARCHAR)
    op.alter_column('python_package_metadata', 'metadata_version', type_=sa.String, existing_type=sa.VARCHAR)
    op.alter_column('python_package_metadata', 'name', type_=sa.String, existing_type=sa.VARCHAR)
    op.alter_column('python_package_metadata', 'summary', type_=sa.String, existing_type=sa.VARCHAR)
    op.alter_column('python_package_metadata', 'version', type_=sa.String, existing_type=sa.VARCHAR)
    op.alter_column('python_package_metadata', 'requires_python', type_=sa.String, existing_type=sa.VARCHAR)
    op.alter_column('python_package_metadata', 'description', type_=sa.String, existing_type=sa.VARCHAR)
    op.alter_column('python_package_metadata', 'description_content_type', type_=sa.String, existing_type=sa.VARCHAR)

    op.alter_column('python_package_metadata_classifier', 'classifier', type_=sa.String, existing_type=sa.VARCHAR)

    op.alter_column('python_package_metadata_platform', 'platform', type_=sa.String, existing_type=sa.VARCHAR)

    op.alter_column('python_package_metadata_supported_platform', 'supported_platform', type_=sa.String, existing_type=sa.VARCHAR)

    op.alter_column('python_package_metadata_requires_external', 'dependency', type_=sa.String, existing_type=sa.VARCHAR)

    op.alter_column('python_package_metadata_project_url', 'project_url', type_=sa.String, existing_type=sa.VARCHAR)

    op.alter_column('python_package_metadata_provides_extra', 'optional_feature', type_=sa.String, existing_type=sa.VARCHAR)

    op.alter_column('python_package_metadata_distutils', 'distutils', type_=sa.String, existing_type=sa.VARCHAR)
    # ### end Alembic commands ###



"""Robust Syncs

Revision ID: 650a13fd0a08
Revises: 9a8ce1e52efb
Create Date: 2019-10-07 14:47:33.441781+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '650a13fd0a08'
down_revision = '9a8ce1e52efb'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('external_python_requirements_lock',
    sa.Column('id', sa.Integer(), autoincrement=True, nullable=False),
    sa.Column('python_package_version_entity_id', sa.Integer(), nullable=False),
    sa.Column('python_software_stack_id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['python_package_version_entity_id'], ['python_package_version_entity.id'], ondelete='CASCADE'),
    sa.ForeignKeyConstraint(['python_software_stack_id'], ['python_software_stack.id'], ondelete='CASCADE'),
    sa.PrimaryKeyConstraint('id', 'python_package_version_entity_id', 'python_software_stack_id')
    )
    op.add_column('identified', sa.Column('python_package_version_entity_id', sa.Integer(), nullable=False))
    op.drop_constraint('identified_python_package_version_id_fkey', 'identified', type_='foreignkey')
    op.create_foreign_key(None, 'identified', 'python_package_version_entity', ['python_package_version_entity_id'], ['id'], ondelete='CASCADE')
    op.drop_column('identified', 'python_package_version_id')
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('identified', sa.Column('python_package_version_id', sa.INTEGER(), autoincrement=False, nullable=False))
    op.drop_constraint(None, 'identified', type_='foreignkey')
    op.create_foreign_key('identified_python_package_version_id_fkey', 'identified', 'python_package_version', ['python_package_version_id'], ['id'], ondelete='CASCADE')
    op.drop_column('identified', 'python_package_version_entity_id')
    op.drop_table('external_python_requirements_lock')
    # ### end Alembic commands ###



"""Add markers and extra needed for resolver

Revision ID: f60593780969
Revises: 1ee67d9a7861
Create Date: 2019-10-02 20:04:59.209567+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'f60593780969'
down_revision = '1ee67d9a7861'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('depends_on', sa.Column('extra', sa.String(length=256), nullable=True))
    op.add_column('depends_on', sa.Column('marker', sa.String(length=256), nullable=True))
    op.add_column('depends_on', sa.Column('marker_evaluation_result', sa.Boolean(), nullable=True))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('depends_on', 'marker_evaluation_result')
    op.drop_column('depends_on', 'marker')
    op.drop_column('depends_on', 'extra')
    # ### end Alembic commands ###



#!/usr/bin/env python3
# thoth-storages
# Copyright(C) 2018, 2019, 2020 Fridolin Pokorny
#
# This program is free software: you can redistribute it and / or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

"""Exceptions for storage adapters and storage handling."""


class ThothStorageException(Exception):
    """A base exception for Thoth storage exception hierarchy."""


class NotFoundError(ThothStorageException):
    """Raised if the given artifact cannot be found."""


class SchemaError(ThothStorageException):
    """Raised if trying to store document with invalid schema."""


class CacheMiss(ThothStorageException):
    """Raised if the requested document was not found in the cache."""


class NotConnected(ThothStorageException):
    """Raised if there was no connection established when communicating with a storage."""


class AlreadyConnected(ThothStorageException):
    """Raised if trying to connect on already connected adapter."""


class DatabaseNotInitialized(ThothStorageException):
    """Raised if trying to perform operations on un-initialized database schema."""


class SolverNameParseError(ThothStorageException):
    """Raised if unable to determine solver information out of solver name run."""


class MultipleFoundError(ThothStorageException):
    """Raised if there are multiple entities in the graph database when querying for a single one."""


class PythonIndexNotRegistered(ThothStorageException):
    """Raised if an attempt to insert a Python package with an index not being registered to the system."""


class UnboundModel(ThothStorageException):
    """Raised if there are done operations on models which do not link to objects stored inside database."""


class PerformanceIndicatorNotRegistered(ThothStorageException):
    """Raised if a performance indicator model which is about to be synced was not found."""


class PythonIndexNotProvided(ThothStorageException):
    """Raised if an attempt to insert a package without an index."""


class SolverNotRun(ThothStorageException):
    """Raised if an attempt to insert a package which was not solved."""


class PythonPackageMetadataAttributeMissing(ThothStorageException):
    """Raised if a Python Package metadata attribute is not included in the class attributes."""


class DistutilsKeyNotKnown(ThothStorageException):
    """Raised if a distutils in Python Package metadata is not known."""


class SortTypeQueryError(ThothStorageException):
    """Raised if a sort key used in a query is not known."""


class NoDocumentIdError(ThothStorageException):
    """Raised if document id is not found in the document."""


class CudaVersionDoesNotMatch(ThothStorageException):
    """Raised if the cuda versions from txt file and nvcc command is different."""



"""Adjust types for conv PI

Revision ID: 1fbd52a03c73
Revises: d0ebc816243c
Create Date: 2020-01-10 18:35:09.115584+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '1fbd52a03c73'
down_revision = 'd0ebc816243c'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.alter_column('pi_conv1d', 'padding',
               existing_type=sa.VARCHAR(length=256),
               type_=sa.Integer(),
               existing_nullable=False,
               postgresql_using='padding::integer')
    op.alter_column('pi_conv2d', 'padding',
               existing_type=sa.VARCHAR(length=256),
               type_=sa.Integer(),
               existing_nullable=False,
               postgresql_using='padding::integer')
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.alter_column('pi_conv2d', 'padding',
               existing_type=sa.Integer(),
               type_=sa.VARCHAR(length=256),
               existing_nullable=False)
    op.alter_column('pi_conv1d', 'padding',
               existing_type=sa.Integer(),
               type_=sa.VARCHAR(length=256),
               existing_nullable=False)
    # ### end Alembic commands ###



import os
import sys
from setuptools import setup
from setuptools.command.test import test as TestCommand
from pathlib import Path


def get_install_requires():
    with open('requirements.txt', 'r') as requirements_file:
        # TODO: respect hashes in requirements.txt file
        res = requirements_file.readlines()
        return [req.split(' ', maxsplit=1)[0] for req in res if req]


def get_test_requires():
    with open('requirements-test.txt', 'r') as requirements_file:
        res = requirements_file.readlines()
        return [req.split(' ', maxsplit=1)[0] for req in res if req]


def get_version():
    with open(os.path.join('thoth', 'storages', '__init__.py')) as f:
        content = f.readlines()

    for line in content:
        if line.startswith('__version__ ='):
            # dirty, remove trailing and leading chars
            return line.split(' = ')[1][1:-2]
    raise ValueError("No version identifier found")


class Test(TestCommand):
    """Introduce test command to run testsuite using pytest."""

    _IMPLICIT_PYTEST_ARGS = [
        'tests/',
        '--timeout=2',
        '--cov=./thoth',
        # '--mypy',
        'thoth/',
        '--capture=no',
        '--verbose',
        '-l',
        '-s',
        '-vv'
    ]

    user_options = [
        ('pytest-args=', 'a', "Arguments to pass into py.test")
    ]

    def initialize_options(self):
        super().initialize_options()
        self.pytest_args = None

    def finalize_options(self):
        super().finalize_options()
        self.test_args = []
        self.test_suite = True

    def run_tests(self):
        import pytest
        passed_args = list(self._IMPLICIT_PYTEST_ARGS)

        if self.pytest_args:
            self.pytest_args = [arg for arg in self.pytest_args.split() if arg]
            passed_args.extend(self.pytest_args)

        sys.exit(pytest.main(passed_args))


VERSION = get_version()
setup(
    name='thoth-storages',
    version=VERSION,
    description='Storage and database adapters available in project Thoth',
    long_description=Path('README.rst').read_text(),
    author='Fridolin Pokorny',
    author_email='fridolin@redhat.com',
    license='GPLv3+',
    packages=[
        'thoth.storages',
        'thoth.storages.graph'
    ],
    package_data={
        'thoth.storages': [
            "py.typed",
            os.path.join('data', 'alembic.ini'),
            os.path.join('data', 'alembic', 'script.py.mako'),
            os.path.join('data', 'alembic', 'env.py'),
            os.path.join('data', 'alembic', 'versions', '*.py'),
        ]
    },
    zip_safe=False,
    install_requires=get_install_requires(),
    tests_require=get_test_requires(),
    cmdclass={'test': Test},
    entry_points={
        'console_scripts': ['thoth-storages=thoth.storages.cli:cli']
    },
    url='https://github.com/thoth-station/storages',
    maintainer='Francesco Murdaca',
    maintainer_email='fmurdaca@redhat.com',
    command_options={
        'build_sphinx': {
            'version': ('setup.py', VERSION),
            'release': ('setup.py', VERSION),
        }
    }
)



"""Add parameters to deal with unsolved pacakges in adviser run

Revision ID: 125a71b49a50
Revises: 74254b596f00
Create Date: 2020-03-23 13:46:21.439043+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '125a71b49a50'
down_revision = '74254b596f00'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('adviser_run', sa.Column('need_re_run', sa.Boolean(), nullable=True))
    op.add_column('adviser_run', sa.Column('re_run_adviser_id', sa.String(length=256), nullable=True))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('adviser_run', 're_run_adviser_id')
    op.drop_column('adviser_run', 'need_re_run')
    # ### end Alembic commands ###



"""Provide is_s2i flag for adviser runs

Revision ID: fcac91b2a3f1
Revises: 9b210f8d5c24
Create Date: 2019-12-07 13:39:32.620452+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'fcac91b2a3f1'
down_revision = '9b210f8d5c24'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('adviser_run', sa.Column('is_s2i', sa.Boolean(), nullable=True))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('adviser_run', 'is_s2i')
    # ### end Alembic commands ###
